@@ -16,8 +16,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-#include "iobuf/iobuf.h"
-#include "msg/msg.h"
+#include "iobuf.h"
+#include "msg.h"
 #include <time.h>
 #include "systime.h"
 #include <stdlib.h>
