@@ -36,8 +36,8 @@ const struct hmac_control_block hmac_sha256 = {
 };
 
 #ifdef SELFTEST_MAIN
-#include "iobuf/obuf.h"
-#include "str/str.h"
+#include "obuf.h"
+#include "str.h"
 
 static void test_hmac(const char* key, const char* data)
 {
@@ -51,7 +51,7 @@ static void test_hmac(const char* key, const char* data)
   obuf_endl(&outbuf);
 }
 
-int main(void)
+MAIN
 {
   test_hmac("\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b\x0b",
 	    "Hi There");
@@ -62,8 +62,6 @@ int main(void)
 	    "\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd"
 	    "\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd"
 	    "\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd\xdd");
-
-  return 0;
 }
 #endif
 #ifdef SELFTEST_EXP
