@@ -179,8 +179,7 @@ void SHA256_final(SHA256_ctx* ctx, uint8* digest)
 }
 
 #ifdef SELFTEST_MAIN
-#include "iobuf/obuf.h"
-#include "str/str.h"
+#include "obuf.h"
 
 static void test(const char* s)
 {
@@ -195,7 +194,7 @@ static void test(const char* s)
   obuf_endl(&outbuf);
 }
 
-int main(void)
+MAIN
 {
   test("abc");
   test("abcdbcdecdefdefgefghfghighijhijkijkljklmklmnlmnomnopnopq");
@@ -207,8 +206,6 @@ int main(void)
   test("For this sample, this 63-byte string will be used as input data");
   test("And this textual data, astonishing as it may appear, is exactly 128 bytes in length, as are both SHA-384 and SHA-512 block sizes");
   test("By hashing data that is one byte less than a multiple of a hash block length (like this 127-byte string), bugs may be revealed.");
-
-  return 0;
 }
 #endif
 #ifdef SELFTEST_EXP
