@@ -1,9 +1,8 @@
 #include <stdlib.h>
 #include <string.h>
-#include "iobuf/iobuf.h"
-#include "str/str.h"
+#include "iobuf.h"
+#include "str.h"
 #include "dict.h"
-#include "load.h"
 
 int dict_load_map(dict* d, const char* filename, int mustexist, char sep,
 		  int (*keyxform)(str*), int (*valxform)(str*))
