@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
-#include "misc.h"
+#include "fmt.h"
 
 /** Format a single character */
 unsigned fmt_char(char* buffer, int ch, unsigned width, char pad)
@@ -30,7 +30,6 @@ unsigned fmt_char(char* buffer, int ch, unsigned width, char pad)
 }
 
 #ifdef SELFTEST_MAIN
-#include "selftest.c"
 MAIN
 {
   char buf[99];
