@@ -1,4 +1,4 @@
-#include "number.h"
+#include "fmt.h"
 
 /** Array of digits for lower-case conversions */
 const char fmt_lcase_digits[36] = "0123456789abcdefghijklmnopqrstuvwxyz";
