@@ -15,7 +15,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
-#include "number.h"
+#include "fmt.h"
 
 static unsigned rec(char* buffer, long num, int sign,
 		    unsigned width, char pad,
@@ -61,7 +61,6 @@ unsigned fmt_snumw(char* buffer, long num, unsigned width, char pad,
 }
 
 #ifdef SELFTEST_MAIN
-#include "selftest.c"
 void test(long num, unsigned width, char pad)
 {
   char buf[FMT_ULONG_LEN];
