@@ -1,5 +1,4 @@
-/* $Id: ucase.c 616 2005-08-19 20:11:01Z bruce $ */
-#include "number.h"
+#include "fmt.h"
 
 /** Array of digits for upper-case conversions */
 const char fmt_ucase_digits[36] = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ";
