@@ -16,7 +16,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 #include <string.h>
-#include "number.h"
+#include "fmt.h"
 
 static unsigned rec(char* buffer, unsigned long num,
 		    unsigned width, char pad,
@@ -59,7 +59,6 @@ unsigned fmt_unumw(char* buffer, unsigned long num, unsigned width, char pad,
 }
 
 #ifdef SELFTEST_MAIN
-#include "selftest.c"
 static void test(unsigned (*fn)(char*, unsigned long, unsigned, char),
 		 unsigned long num, unsigned width, char pad)
 {
