@@ -15,7 +15,7 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
 #include "ibuf.h"
-#include "str/str.h"
+#include "str.h"
 
 /** Read a line from the \c ibuf into a dynamic string, terminated by a CR+LF pair. */
 int ibuf_getstr_crlf(ibuf* in, struct str* s)
@@ -34,7 +34,6 @@ int ibuf_getstr_crlf(ibuf* in, struct str* s)
 
 #ifdef SELFTEST_MAIN
 #include <unistd.h>
-#include "selftest.c"
 
 ibuf in = {
   { -1, "\n\r\na\nb\r\nd", 9, 9, 0, 0, 0, 0, 0 },
