@@ -1,6 +1,6 @@
 #include <string.h>
 #include "obuf.h"
-#include "fmt/multi.h"
+#include "fmt.h"
 
 /** Write a formatted string using \c fmt_multi from a \c va_list */
 int obuf_putfv(obuf* out, const char* format, va_list ap)
@@ -34,7 +34,6 @@ int obuf_putf(obuf* out, const char* format, ...)
 }
 
 #ifdef SELFTEST_MAIN
-#include "selftest.c"
 MAIN
 {
   obuf_putf(&outbuf, "d{bar}x", 10, 20); NL();
