@@ -1,17 +1,16 @@
-#include "misc.h"
+#include "fmt.h"
 
-unsigned long strtou(const char* str, const char** end)
+unsigned long strtou(const char* s, const char** end)
 {
   unsigned long u;
   unsigned digit;
-  for (u = 0; (digit = *str - '0') <= 9; ++str)
+  for (u = 0; (digit = *s - '0') <= 9; ++s)
     u = u * 10 + digit;
-  *end = str;
+  *end = s;
   return u;
 }
 
 #ifdef SELFTEST_MAIN
-#include "selftest.c"
 void test(const char* s)
 {
   const char* end;
