@@ -1,4 +1,4 @@
-#include "misc.h"
+#include "fmt.h"
 
 char* utoa2(unsigned long i, char* buf)
 {
@@ -13,7 +13,6 @@ char* utoa2(unsigned long i, char* buf)
 }
 
 #ifdef SELFTEST_MAIN
-#include "selftest.c"
 void test(unsigned long u)
 {
   char buf[32];
