@@ -2,7 +2,7 @@
 #include <string.h>
 #include <sys/types.h>
 #include <unistd.h>
-#include "iobuf/obuf.h"
+#include "obuf.h"
 #include "msg.h"
 
 static pid_t pid = 0;
@@ -49,7 +49,6 @@ void msg_commonf(const char* type,
 }
 
 #ifdef SELFTEST_MAIN
-#include "selftest.c"
 MAIN
 {
   warnf("ss", "a", "b");
