@@ -1,6 +1,5 @@
-/* $Id: acceptu.c 639 2005-11-21 04:43:14Z bruce $ */
 /* net/accept4.c - Accept an UNIX domain connection
- * Copyright (C) 2001,2005  Bruce Guenter <bruce@untroubled.org>
+ * Copyright (C) 2006  Bruce Guenter <bruce@untroubled.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,7 +25,7 @@
 int socket_acceptu(int sock)
 {
   struct sockaddr_un sa;
-  int dummy;
+  socklen_t dummy;
 
   dummy = sizeof sa;
   return accept(sock, (struct sockaddr*)&sa, &dummy);
