@@ -1,4 +1,3 @@
-/* $Id: getaddr4.c 639 2005-11-21 04:43:14Z bruce $ */
 /* net/getaddr4.c - Determine the IPv4 address of a socket
  * Copyright (C) 2001,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -27,7 +26,7 @@
 int socket_getaddr4(int sock, ipv4addr* addr, ipv4port* port)
 {
   struct sockaddr_in sa;
-  int size;
+  socklen_t size;
   size = sizeof sa;
   if (getsockname(sock, (struct sockaddr*)&sa, &size) == -1) return 0;
   if (sa.sin_family != AF_INET) return 0;
