@@ -1,4 +1,3 @@
-/* $Id: getaddr6.c 639 2005-11-21 04:43:14Z bruce $ */
 /* net/getaddr6.c - Determine the IPv6 address of a socket
  * Copyright (C) 2004,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -29,7 +28,7 @@ int socket_getaddr6(int sock, ipv6addr* addr, ipv6port* port)
 {
 #if HASIPV6
   struct sockaddr_in6 sa;
-  int size;
+  socklen_t size;
   size = sizeof sa;
   if (getsockname(sock, (struct sockaddr*)&sa, &size) == -1) return 0;
   if (sa.sin6_family != AF_INET6) return 0;
