@@ -1,4 +1,3 @@
-/* $Id: recv4.c 639 2005-11-21 04:43:14Z bruce $ */
 /* net/recv4.c - Receive a datagram from a UDP socket
  * Copyright (C) 2001,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -28,7 +27,7 @@ int socket_recv4(int sock, char* buffer, unsigned buflen,
 		 ipv4addr* ip, ipv4port* port)
 {
   struct sockaddr_in sa;
-  int dummy = sizeof sa;
+  socklen_t dummy = sizeof sa;
   int r;
 
   r = recvfrom(sock, buffer, buflen, 0, (struct sockaddr*)&sa, &dummy);
