@@ -1,4 +1,3 @@
-/* $Id: recv6.c 639 2005-11-21 04:43:14Z bruce $ */
 /* net/recv6.c - Receive a datagram from a UDP socket
  * Copyright (C) 2004,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -30,7 +29,7 @@ int socket_recv6(int sock, char* buffer, unsigned buflen,
 {
 #if HASIPV6
   struct sockaddr_in6 sa;
-  int dummy = sizeof sa;
+  socklen_t dummy = sizeof sa;
   int r;
 
   r = recvfrom(sock, buffer, buflen, 0, (struct sockaddr*)&sa, &dummy);
