@@ -1,4 +1,3 @@
-/* $Id$ */
 /* pwcmp/client.c - Password comparison client library
  * Copyright (C) 2001  Bruce Guenter <bruce@untroubled.org>
  *
@@ -82,7 +81,7 @@ static int pwcmp_start_pipe(const char* module)
     dup2(pipe1[1], 1);
     close(pipe0[0]); close(pipe0[1]);
     close(pipe1[0]); close(pipe1[1]);
-    execlp(module, module, 0);
+    execlp(module, module, NULL);
     _exit(1);
   }
   else {
