@@ -1,14 +1,18 @@
+#ifndef SELFTEST_C
+
 #include <errno.h>
 #include <string.h>
+#include <unistd.h>
 
-#include "iobuf/iobuf.h"
-#include "msg/msg.h"
-#include "str/str.h"
+#include "iobuf.h"
+#include "msg.h"
+#include "path.h"
+#include "str.h"
 
 const char program[] = "selftest";
 const int msg_show_pid = 0;
 
-void NL(void) { obuf_putc(&outbuf, LF); }
+void NL(void) { obuf_putc(&outbuf, LF); obuf_flush(&outbuf); }
 
 void debugstr(const str* s)
 {
@@ -54,8 +58,19 @@ int debugsys(int result)
   return result;
 }
 
+void makefile(str* fn, const char* content)
+{
+  long len = strlen(content);
+  int fd = path_mktemp("./selftest.tmpfile", fn);
+  if (fd < 0) die1(1, "Could not create temporary file");
+  if (write(fd, content, len) != len || close(fd) != 0) {
+    unlink(fn->s);
+    die1(1, "Could not write temporary file");
+  }
+}
+
 #define MAIN void selftest(void)
-MAIN;
+extern MAIN;
 
 int main(void)
 {
@@ -64,3 +79,5 @@ int main(void)
   obuf_flush(&errbuf);
   return 0;
 }
+
+#endif
