@@ -12,25 +12,30 @@ trap 'echo "Cleaning up $t"; rm -r $t' EXIT
 do_test() {
   echo "Testing $1"
   rm -f $t/*
-  sed -e '1,/^#ifdef SELFTEST_EXP$/d' -e '/^#endif/,$d' $1 >$t/test.exp
 
   sed -e 's/-o ${base}.o//' compile | \
-  sh -s $1 -DSELFTEST_MAIN -o $t/test.o || {
+  sh -s $1 -DSELFTEST_MAIN -o $t/test.o -include selftest.c || {
     echo "=====> Compile failed! <====="
     return 1
   }
 
-  ./load $t/test .libs/libbg.a .libs/libbg-sysdeps.a || {
+  ./load $t/test .libs/libbg.a || {
     echo "=====> Load failed! <====="
     return 1
   }
 
   ( cd $t && ./test >./test.out 2>&1; ) || {
+    echo "=====> Test output <====="
+    cat -v $t/test.out
     echo "=====> Test failed! <====="
     return 1
   }
 
-  cat -v $t/test.out | $DIFF $t/test.exp - || {
+  ./selftest-cmp $1 $t/test.out || {
+    echo "=====> Expected output <====="
+    sed -e '1,/^#ifdef SELFTEST_EXP/d' -e '/^#endif/,$d' $1
+    echo "=====> Test output <====="
+    cat -v $t/test.out
     echo "=====> Output failed! <====="
     return 1
   }
