@@ -1,5 +1,5 @@
 /* str/catunumw.c - Append an unsigned integer
- * Copyright (C) 2003,2005  Bruce Guenter <bruce@untroubled.org>
+ * Copyright (C) 2015  Bruce Guenter <bruce@untroubled.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -15,28 +15,17 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
+#include "fmt.h"
 #include "str.h"
 
 /** Append an unsigned integer, optionally padded to a minimum width */
 int str_catunumw(str* s, unsigned long in, unsigned width, char pad,
 		 unsigned base, const char* digits)
 {
-  unsigned long tmp;
-  unsigned size;
-  unsigned padsize;
-  unsigned i;
-  
-  if (in < base)
-    size = 1;
-  else
-    for (tmp = in, size = 0; tmp; tmp /= base, ++size) ;
-  padsize = (width > size) ? width - size : 0;
-  if (!str_realloc(s, s->len + padsize+size)) return 0;
-  while (padsize--)
-    s->s[s->len++] = pad;
-  for (i = size; i-- > 0; in /= base)
-    s->s[s->len+i] = digits[in % base];
-  s->len += size;
+  unsigned len = fmt_unumw(0, in, width, pad, base, digits);
+
+  if (!str_realloc(s, s->len + len)) return 0;
+  s->len += fmt_unumw(s->s + s->len, in, width, pad, base, digits);
   s->s[s->len] = 0;
   return 1;
 }
