@@ -1,5 +1,5 @@
 /* str/catxw.c - Append an hexadecimal number
- * Copyright (C) 2002,2005  Bruce Guenter <bruce@untroubled.org>
+ * Copyright (C) 2015  Bruce Guenter <bruce@untroubled.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -15,16 +15,17 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
+#include "fmt.h"
 #include "str.h"
 
 /** Append an unsigned integer in hexadecimal. */
 int str_catxw(str* s, unsigned long in, unsigned width, char pad)
 {
-  return str_catunumw(s, in, width, pad, 10, str_lcase_digits);
+  return str_catunumw(s, in, width, pad, 10, fmt_lcase_digits);
 }
 
 /** Append an unsigned integer in hexadecimal, padded to a minimum width. */
 int str_catx(str* s, unsigned long in)
 {
-  return str_catunumw(s, in, 0, 0, 10, str_lcase_digits);
+  return str_catunumw(s, in, 0, 0, 10, fmt_lcase_digits);
 }
