@@ -1,5 +1,5 @@
 /* str/catuwll.c - Append an unsigned long long integer
- * Copyright (C) 2003,2005  Bruce Guenter <bruce@untroubled.org>
+ * Copyright (C) 2015  Bruce Guenter <bruce@untroubled.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -15,17 +15,18 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  */
+#include "fmt.h"
 #include "str.h"
 
 /** Append an unsigned long long integer in hexadecimal. */
 int str_catxll(str* s, unsigned long long in)
 {
-  return str_catullnumw(s, in, 0, 0, 10, str_lcase_digits);
+  return str_catullnumw(s, in, 0, 0, 10, fmt_lcase_digits);
 }
 
 /** Append an unsigned long long integer in hexadecimal, padded to a
     minimum width. */
 int str_catxwll(str* s, unsigned long long in, unsigned width, char pad)
 {
-  return str_catullnumw(s, in, width, pad, 10, str_lcase_digits);
+  return str_catullnumw(s, in, width, pad, 10, fmt_lcase_digits);
 }
