@@ -1,7 +1,7 @@
 #include <string.h>
 #include "str.h"
-#include "iter.h"
-#include "env.h"
+#include "striter.h"
+#include "envstr.h"
 
 /** Find the named variable in the environment string.
  * \returns a pointer to the \b start of the assignment.
@@ -18,7 +18,6 @@ const char* envstr_find(const struct str* env, const char* var, long len)
 }
 
 #ifdef SELFTEST_MAIN
-#include "selftest.c"
 MAIN
 {
   static const str env = {"A=1\0B=2\0C=3\0", 12, 0};
