@@ -1,6 +1,6 @@
 #include <string.h>
 #include "str.h"
-#include "env.h"
+#include "envstr.h"
 
 /** Adds the assignments from the array of pointers to the environment
  * string.
@@ -17,7 +17,6 @@ int envstr_from_array(struct str* env, char** array, int overwrite)
 }
 
 #ifdef SELFTEST_MAIN
-#include "selftest.c"
 MAIN
 {
   static str env;
