@@ -1,7 +1,7 @@
 #include <string.h>
 #include "str.h"
-#include "iter.h"
-#include "env.h"
+#include "striter.h"
+#include "envstr.h"
 
 /** Get the value of an assignment from an environment string. */
 const char* envstr_get(const struct str* env, const char* var)
@@ -13,7 +13,6 @@ const char* envstr_get(const struct str* env, const char* var)
 }
 
 #ifdef SELFTEST_MAIN
-#include "selftest.c"
 MAIN
 {
   static const str env = {"A=1\0B=2\0C=3\0", 12, 0};
