@@ -1,8 +1,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include "str.h"
-#include "iter.h"
-#include "env.h"
+#include "striter.h"
+#include "envstr.h"
 
 /** Make a \c environ compatable array of pointers to the environment
  * string.
@@ -27,7 +27,6 @@ char** envstr_make_array(const struct str* env)
 }
 
 #ifdef SELFTEST_MAIN
-#include "selftest.c"
 MAIN
 {
   static const str env = {"A=1\0B=2\0C=3\0", 12, 0};
