@@ -1,6 +1,6 @@
 #include <string.h>
 #include "str.h"
-#include "env.h"
+#include "envstr.h"
 
 /** Put an assignment, in \c NAME=value format, into the environment
  * string.
@@ -22,7 +22,6 @@ int envstr_put(struct str* env, const char* asgn, int overwrite)
 }
 
 #ifdef SELFTEST_MAIN
-#include "selftest.c"
 MAIN
 {
   static str env;
