@@ -1,5 +1,4 @@
-/* $Id: tryclockgettime.c 616 2005-08-19 20:11:01Z bruce $ */
-#include <time.h>
+#include "systime.h"
 
 int main(void)
 {
