@@ -2,10 +2,9 @@
 #include <unistd.h>
 
 #include "sysdeps.h"
-#include "unix/cloexec.h"
-#include "unix/nonblock.h"
-#include "unix/sig.h"
-#include "unix/selfpipe.h"
+#include "unix.h"
+#include "sig.h"
+#include "selfpipe.h"
 
 static int fds[2] = { -1, -1 };
 
@@ -63,7 +62,6 @@ void selfpipe_close(void)
 #ifdef SELFTEST_MAIN
 #include <errno.h>
 #include <signal.h>
-#include "selftest.c"
 void puti(const char* word, long i)
 {
   obuf_put2s(&outbuf, word, ": ");
